8. Resources — setupjavax documentation

# 8. Resources

Home

- Sourceforge.net: https://sourceforge.net/projects/setupjavax/

Online Documents

- Sourceforge.net: https://setupjavax.sourceforge.io/

Runtime Repository

- Python Package Index: https://pypi.org/project/setupjavax/

Downloads

- bitbucket.org: https://bitbucket.org/acue/setupjavax/

- github.com: https://github.com/ArnoCan/setupjavax/

- Python Package Index: https://pypi.org/project/setupjavax/

- Sourceforge.net: https://sourceforge.net/projects/setupjavax/